@@ -97,6 +97,11 @@ class Files:
 
         :param path: Default save path for workbook
         :param fmt:  Format of workbook, i.e. xlsx or xls
+        
+        Example:  
+
+            Create Workbook   SalesData2.xlsx 
+
         """
         if self.workbook:
             self.close_workbook()
@@ -116,6 +121,11 @@ class Files:
         """Open an existing Excel workbook.
 
         :param path: path to Excel file
+        
+        Example:  
+
+            Open Workbook           SalesData.xlsx 
+        
         """
         if self.workbook:
             self.close_workbook()
@@ -125,7 +135,13 @@ class Files:
         return self.workbook
 
     def close_workbook(self):
-        """Close the active workbook."""
+        """Close the active workbook.
+        
+        Example:  
+
+            Close Workbook     SalesData2.xlsx 
+            
+        """
         if self.workbook:
             self.logger.info("Closing workbook: %s", self.workbook)
             self.workbook.close()
@@ -136,6 +152,11 @@ class Files:
 
         :param path: Path to save to. If not given, uses path given
                      when opened or created.
+                     
+        Example: 
+
+            Save Workbook
+            
         """
         assert self.workbook, "No active workbook"
 
@@ -158,17 +179,35 @@ class Files:
         return self.workbook.save(path)
 
     def list_worksheets(self):
-        """List all names of worksheets in the given workbook."""
+        """List all names of worksheets in the given workbook.
+        
+        Example:  
+
+            ${list}   List Worksheets
+            
+        """
         assert self.workbook, "No active workbook"
         return self.workbook.sheetnames
 
     def worksheet_exists(self, name):
-        """Return True if worksheet with given name is in workbook."""
+        """Return True if worksheet with given name is in workbook.
+        
+        Example: 
+
+            Worksheet Exists   sheet1 
+        
+        """
         assert self.workbook, "No active workbook"
         return bool(str(name) in self.list_worksheets())
 
     def get_active_worksheet(self):
-        """Get the name of the worksheet which is currently active."""
+        """Get the name of the worksheet which is currently active.
+        
+        Example:  
+
+            ${worksheet_name}   Get Active Worksheet
+            
+        """
         assert self.workbook, "No active workbook"
         return self.workbook.active
 
@@ -176,6 +215,11 @@ class Files:
         """Set the active worksheet.
 
         :param value: Index or name of worksheet
+        
+        Example: 
+
+            Set Active Worksheet   sheet1 
+        
         """
         assert self.workbook, "No active workbook"
         self.workbook.active = value
@@ -186,6 +230,11 @@ class Files:
         :param name:     Name of new worksheet
         :param content:  Optional content for worksheet
         :param exist_ok: If `False`, raise an error if name is already in use
+        
+        Example:  
+        
+            Create Worksheet   sheet2 
+
         """
         assert self.workbook, "No active workbook"
         if name in self.workbook.sheetnames and not exist_ok:
@@ -204,6 +253,12 @@ class Files:
         :param name:   Name of worksheet to read
         :param header: If `True`, use the first row of the worksheet
                        as headers for the rest of the rows.
+                       
+        Example:  
+
+            ${list_of_values} Read Worksheet   sheet1 
+            Log  ${list_of_values} 
+
         """
         assert self.workbook, "No active workbook"
         return self.workbook.read_worksheet(name, header, start)
@@ -217,6 +272,12 @@ class Files:
                        as headers for the rest of the rows.
         :param trim:   Remove all empty rows from the end of the worksheet
         :param start:  Row index to start reading data from (1-indexed)
+        
+        Example:   
+
+            ${a}  Read Worksheet As Table      data77  
+            Log  ${a} 
+
         """
         tables = Tables()
         sheet = self.read_worksheet(name, header, start)
@@ -229,6 +290,27 @@ class Files:
         :param name:    Name of worksheet to append to
         :param header:  Set rows according to existing header row
         :param start:   Start of data, NOTE: Only required when headers is True
+        
+        Example:  
+
+        Creating new Excel 
+
+            Create Workbook  my_new_excel.xlsx 
+
+            FOR    ${index}    IN RANGE    20 
+
+                &{row}=       Create Dictionary 
+
+                ...           Row No   ${index} 
+
+                ...           Amount   ${index * 25} 
+
+                Append Rows to Worksheet  ${row}  header=${TRUE} 
+
+            END 
+
+            Save Workbook 
+        
         """
         assert self.workbook, "No active workbook"
         return self.workbook.append_worksheet(name, content, header, start)
@@ -237,6 +319,11 @@ class Files:
         """Remove a worksheet from the active workbook.
 
         :param name: Name of worksheet to remove
+        
+        Example:  
+
+            Remove Worksheet     sheet1 
+            
         """
         assert self.workbook, "No active workbook"
         self.workbook.remove_worksheet(name)
@@ -246,6 +333,11 @@ class Files:
 
         :param src_name: Current name of worksheet
         :param dst_name: Future name of worksheet
+        
+        Example: 
+
+            Rename Worksheet     sheet1   sheet2 
+
         """
         assert self.workbook, "No active workbook"
         self.workbook.rename_worksheet(dst_name, src_name)
@@ -254,6 +346,11 @@ class Files:
         """Find the first empty row after existing content.
 
         :param name:    Name of worksheet
+        
+        Example:  
+
+            Find Empty Row   sheet2 
+
         """
         assert self.workbook, "No active workbook"
         return self.workbook.find_empty_row(name)
@@ -265,6 +362,17 @@ class Files:
         :param column:  Name or index of column, e.g. C or 7
         :param value:   New value of cell
         :param name:    Name of worksheet
+        
+        Example: 
+
+            Set Worksheet Value 
+
+            …row=1 
+
+            …column=1 
+
+            …value=New york 
+
         """
         assert self.workbook, "No active workbook"
         self.workbook.set_cell_value(row, column, value, name)
