@@ -436,6 +436,9 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath
         :raises ValueError: if file descriptor for the file is not found
+        Example:
+            | Close PDF Document | C:\\Users\\MM\\Downloads\\source.pdf |
+            | Close PDF Document | source_pdf=C:\\Users\\MM\\Downloads\\source.pdf |
         """
         if str(source_pdf) not in self.fileobjects.keys():
             raise ValueError('PDF "%s" is not open' % source_pdf)
@@ -451,6 +454,9 @@ class PDF(FPDF, HTMLMixin):
         """Set output directory where target files are saved to.
 
         :param outdir: output directory path, default to current directory
+        Example:
+            | Set Output Directory | C:\\Users\\MM\\Documents\\ |
+            | Set Output Directory | outdir=C:\\Users\\MM\\Documents\\ |
         """
         self.output_directory = Path(outdir)
 
@@ -458,6 +464,8 @@ class PDF(FPDF, HTMLMixin):
         """Get output directory where target files are saved to.
 
         :return: absolute filepath as string
+        Example:
+            | ${res} | Get Output Directory |
         """
         return str(self.output_directory)
 
@@ -468,6 +476,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath to the source pdf
         :raises ValueError: if PDF is already open
+        Example:
+            | Open PDF Document | C:\\Users\\MM\\Downloads\\null.pdf |
         """
         if source_pdf is None:
             raise ValueError("Source PDF is missing")
@@ -488,6 +498,8 @@ class PDF(FPDF, HTMLMixin):
         :param source_pdf: filepath
         :raises ValueError: if PDF filepath is not given and there are no active
             file to activate
+        Example:
+            | Switch To PDF Document | C:\\Users\\MM\\Downloads\\null.pdf |
         """
         if source_pdf is not None and str(source_pdf) not in self.fileobjects.keys():
             self.open_pdf_document(source_pdf)
@@ -508,6 +520,9 @@ class PDF(FPDF, HTMLMixin):
         """Adds pages into PDF documents.
 
         :param pages: number of pages to add, defaults to 1
+        Example:
+            | Add Pages |
+            | Add Pages | pages=3 |
         """
         for _ in range(int(pages)):
             self.add_page()
@@ -521,6 +536,9 @@ class PDF(FPDF, HTMLMixin):
         :param source_pdf: filepath to the source pdf
         :param target_pdf: filename to the target pdf, stored by default
             to `output_directory`
+        Example:
+            | Add Pages To Document | 3 | C:\\Users\\MM\\Downloads\\source.pdf | C:\\Users\\MM\\Downloads\\target.pdf |
+            | Add Pages To Document | pages=3 | source_pdf=C:\\Users\\MM\\Downloads\\source.pdf | target_pdf=C:\\Users\\MM\\Downloads\\target.pdf |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -553,6 +571,8 @@ class PDF(FPDF, HTMLMixin):
         :param create_dirs: directory structure is created if it is missing,
          default `True`
         :param exists_ok: file is overwritten if it exists, default `True`
+        Example:
+            | Template Html To Pdf | template=C:\\Users\\MM\\Downloads\\htmlFile.html | filename=C:\\Users\\MM\\Downloads\\htmlToPdf.pdf |
         """
         required_param([template, filename], "template_html_to_pdf")
         variables = variables or {}
@@ -581,6 +601,8 @@ class PDF(FPDF, HTMLMixin):
         :param create_dirs: directory structure is created if it is missing,
          default `True`
         :param exists_ok: file is overwritten if it exists, default `True`
+        Example:
+            | Html To Pdf | content=C:\\Users\\MM\\Downloads\\content.html | filename=C:\\Users\\MM\\Downloads\\htmlToPdf.pdf |
         """
         required_param([content, filename], "html_to_pdf")
         variables = variables or {}
@@ -611,6 +633,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath to the source pdf
         :return: dictionary of PDF information
+        Example:
+            | ${res} | Get Info | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf |
         """
         self.switch_to_pdf_document(source_pdf)
         pdf = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -646,6 +670,9 @@ class PDF(FPDF, HTMLMixin):
             to `output_directory`
         :param pages: page numbers to extract from PDF (numbers start from 0)
             if None then extracts all pages
+        Example:
+            | Extract Pages From PDF | C:\\Users\\MM\\Downloads\\source.pdf | C:\\Users\\MM\\Downloads\\target.pdf | 2 |
+            | Extract Pages From PDF | source_pdf=C:\\Users\\MM\\Downloads\\source.pdf | target_pdf=C:\\Users\\MM\\Downloads\\target.pdf | pages=2 |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -669,6 +696,8 @@ class PDF(FPDF, HTMLMixin):
         :param source_pdf: filepath to the source pdf
         :param pages: page numbers to get text (numbers start from 0)
         :return: dictionary of pages and their texts
+        Example:
+            | ${res} | Get Text From Pdf | source_pdf=C:\\Users\\MM\\Downloads\\htmlToPdf.pdf | pages=1 |
         """
         self.switch_to_pdf_document(source_pdf)
         if self.AutoSphere_pdf_document is None:
@@ -704,6 +733,8 @@ class PDF(FPDF, HTMLMixin):
         :param pages: page numbers to extract from PDF (numbers start from 0)
         :param clockwise: directorion that page will be rotated to, default True
         :param angle: number of degrees to rotate, default 90
+        Example:
+            | Page Rotate | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf | target_pdf=C:\\Users\\MM\\Downloads\\rotatedContent.pdf | pages=1 | clockwise=True | angel=90 |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -734,6 +765,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath to the source pdf
         :return: True if file is encrypted
+        Example:
+            | ${res} | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -757,6 +790,9 @@ class PDF(FPDF, HTMLMixin):
             default same `user_pwd`
         :param use_128bit: whether to 128bit encryption, when false 40bit
             encryption is used, default True
+        Example:
+            | Pdf Encrypt | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf | target_pdf=C:\\Users\\MM\\Downloads\\encrypetdPdt.pdf |
+            user_pwd=UserPaSsW0rd | owner_pwd=0wneRpAssW0rd | use_128bit=True |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -779,6 +815,9 @@ class PDF(FPDF, HTMLMixin):
         :param password: password as a string
         :return: True if decrypt was successful, else False or Exception
         :raises ValueError: on decryption errors
+        Example:
+            | Pdf Decrypt | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf | target_pdf=C:\\Users\\MM\\Downloads\\decryptedContent.pdf |
+            password=PassW0rD |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -816,6 +855,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath to the source pdf
         :raises PdfReadError: if file is encrypted or other restrictions are in place
+        Example:
+            | ${res} | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject)
@@ -826,6 +867,8 @@ class PDF(FPDF, HTMLMixin):
         used for text searches for example.
 
         :param source_pdf: source
+        Example:
+            | Parse Pdf | source_pdf=C:\\Users\\MM\\Downloads\\content.pdf |
         """
         if source_pdf is not None:
             self.switch_to_pdf_document(source_pdf)
@@ -877,6 +920,9 @@ class PDF(FPDF, HTMLMixin):
         :param source_pdf: source PDF with fields to update
         :param target_pdf: updated target PDF
         :param newvals: dictionary with key values to update
+         Example:
+            | Update Field Values | source_pdf=C:\\Users\\MM\\Downloads\\source.pdf | target_pdf=C:\\Users\\MM\\Downloads\\target.pdf |
+            newvals={'b': '2', 'd': '4'} |
         """
         self.switch_to_pdf_document(source_pdf)
         reader = PyPDF2.PdfFileReader(self.active_fileobject, strict=False)
@@ -928,6 +974,8 @@ class PDF(FPDF, HTMLMixin):
         :param replace_none_value: if value is None replace it with key name,
             defaults to False
         :return: dictionary of input key values or `None`
+        Example:
+            | ${InputDictionary} | Get Input Fields | source_pdf=C:\\Users\\MM\\Downloads\\source.pdf | replace_none_value=False/True |
         """
         record_fields = {}
         if source_pdf is None and self.active_fields:
@@ -984,6 +1032,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param locator: element to search for
         :return: True if element was found
+        Example:
+            | ${res} | Set Anchor To Element | locator=text:Hi |
         """
         self.logger.info("Set anchor to element: ('locator=%s')", locator)
         if self.AutoSphere_pdf_document is None:
@@ -1041,6 +1091,8 @@ class PDF(FPDF, HTMLMixin):
             used when direction is 'top' or 'bottom', default `False`
         :param regexp: expected format of value to match, defaults to None
         :return: closest matching text or `None`
+        Example:
+            | ${res} | Get Value From Anchor | locator=text:Hi | pagenum=1 | direction=top | strict=False | regexp=*PUBLIC* |
         """
         self.logger.debug(
             "get_value_from_anchor: ('locator=%s', 'direction=%s', 'regexp=%s')",
@@ -1135,6 +1187,8 @@ class PDF(FPDF, HTMLMixin):
         PDF needs to be parsed before elements can be found.
 
         :return: dictionary of figures divided into pages
+        Example:
+            | ${res} | Get All Figures |
         """
         if self.AutoSphere_pdf_document is None:
             raise ValueError("PDF has not been parsed yet")
@@ -1153,6 +1207,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param field_name: field to update
         :param value: new value for the field
+        Example:
+            | Set Field Value | field_name=Age | value=18 |
         """
         if not self.active_fields:
             self.get_input_fields()
@@ -1190,6 +1246,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param text: this text will be replaced
         :param replace: used to replace `text`
+        Example:
+            | Replace Text | tex=PUBLIC | replace=PRIVATE |
         """
         if self.AutoSphere_pdf_document is None:
             self.parse_pdf()
@@ -1212,11 +1270,14 @@ class PDF(FPDF, HTMLMixin):
         :param target: filepath of target PDF
         :param coverage: [description], defaults to 0.2
         :raises ValueError: [description]
+
+        Example:
+            | Add Image To PDF | C:\\Users\\MM\\Desktop\\test.png | C:\\Users\\MM\\Downloads\\sample.pdf | C:\\Users\\MM\\Documents\\sample.pdf |
         """
         if target is None:
             raise ValueError("Target PDF needs to be set")
         if source is None and self.active_pdf:
-            source = self.active_pdf
+            source = self.active_pdff
         elif source is None and self.active_pdf is None:
             raise ValueError("No source PDF exists")
         temp_pdf = os.path.join(tempfile.gettempdir(), "temp.pdf")
@@ -1254,10 +1315,10 @@ class PDF(FPDF, HTMLMixin):
     ):
         """Save current over itself or to `target_pdf`
 
-        :param source: filepath to source PDF
-        :param target: filepath to target PDF
-        :param use_modified_reader: needs to be set to `True` if
-            using modified PDF reader
+        :param source: filepath to source PDF :param target: filepath to target PDF :param use_modified_reader: needs
+        to be set to `True` if using modified PDF reader Example: | Save Pdf |
+        source=C:\\Users\\MM\\Desktop\\test.png | target=C:\\Users\\MM\\Downloads\\sample.pdf |
+        use_modified_reader=True |
         """
         if not use_modified_reader:
             self.get_input_fields(source)
@@ -1292,6 +1353,8 @@ class PDF(FPDF, HTMLMixin):
 
         :param source_pdf: filepath
         :return: XML content
+        Example:
+            | ${res} | Dump Pdf As Xml | C:\\Users\\MM\\Downloads\\source.pdf |
         """
         self.switch_to_pdf_document(source_pdf)
         if self.AutoSphere_pdf_document is None:
